@@ -128,12 +128,14 @@ where
     A::Connection: AsyncRead + AsyncWrite + Unpin + 'static,
     A::Error: std::error::Error,
     T: AsyncTls<A::Connection>,
-    Self: Unpin,
 {
     /// Accept the next connection
     ///
     /// This is essentially an alias to `self.next()` with a more domain-appropriate name.
-    pub fn accept(&mut self) -> impl Future<Output = Option<<Self as Stream>::Item>> + '_ {
+    pub fn accept(&mut self) -> impl Future<Output = Option<<Self as Stream>::Item>> + '_
+    where
+        Self: Unpin,
+    {
         self.next()
     }
 
@@ -143,6 +145,15 @@ where
     pub fn replace_acceptor(&mut self, acceptor: T) {
         self.tls = acceptor;
     }
+
+    /// Replaces the Tls Acceptor configuration from a pinned reference to `Self`.
+    ///
+    /// This is useful if your listener is `!Unpin`.
+    ///
+    /// This can be used to change the certificate used at runtime.
+    pub fn replace_acceptor_pin(self: Pin<&mut Self>, acceptor: T) {
+        *self.project().tls = acceptor;
+    }
 }
 
 impl<A, T> Stream for TlsListener<A, T>
